django-uwsgi
~~~~~~~~~~~~

Django related examples/tricks/modules for uWSGI


Screenshots
~~~~~~~~~~~

`django-debug-toolbar <http://django-debug-toolbar.readthedocs.org/en/latest/>`_ panel

.. image:: docs/screenshots/screenshot1.png


`Wagtail <https://github.com/torchbox/wagtail>`_ admin interface:

.. image:: docs/screenshots/screenshot2.png

.. image:: docs/screenshots/screenshot3.png


Documentation
~~~~~~~~~~~~~

`Read the documentation at rtfd.org <http://django-uwsgi.rtfd.org/>`_

Contributors
~~~~~~~~~~~~

See `CONTRIBUTORS <https://github.com/unbit/django-uwsgi/CONTRIBUTORS>`_

License
~~~~~~~

`MIT <https://github.com/unbit/django-uwsgi/LICENSE>`_
